<?php

if(!class_exists('ubam_wp_paginate')) {
    class ubam_wp_paginate {
        var $php_self;
        var $rows_per_page = 10; //Number of records to display per page
        var $total_rows = 0; //Total number of rows returned by the query
        var $links_per_page = 5; //Number of links to display per page
        var $sql = "";
        var $debug = false;
        var $page = 1;
        var $max_pages = 0;
        var $offset = 0;
		var $js_function;
        
        /**
         * Constructor
         *
         * @param resource $connection Mysql connection link
         * @param string $sql SQL query to paginate. Example : SELECT * FROM users
         * @param integer $rows_per_page Number of records to display per page. Defaults to 10
         * @param integer $links_per_page Number of links to display per page. Defaults to 5
         * @param string $append Parameters to be appended to pagination links 
         */
        
        function ubam_wp_paginate($sql, $rows_per_page = 10, $links_per_page = 5, $total_rows = 0, $js_function = "") {
            $this->sql = $sql;
            $this->rows_per_page = (int)$rows_per_page;
            if (intval($links_per_page ) > 0) {
                $this->links_per_page = (int)$links_per_page;
            } else {
                $this->links_per_page = 5;
            }
            $this->js_function = $js_function;
            $this->total_rows = $total_rows;
            $this->php_self = htmlspecialchars($_SERVER['PHP_SELF'] );
            if (isset($_GET['wpppage'] )) {
                $this->page = intval($_GET['wpppage'] );
            }
        }
        
        /**
         * Executes the SQL query and initializes internal variables
         *
         * @access public
         * @return resource
         */
        function paginate($page=1) {
			global $wpdb;

			if($page > 0) $this->page = $page;
            
            if($this->total_rows == 0) {
                $FROMstart = stripos($this->sql, ' FROM ');
                $countSQL = "SELECT COUNT(*) " . substr($this->sql, $FROMstart);
                
                //Find total number of rows
                $all_rs = $wpdb->get_var($countSQL);
                if (! $all_rs) {
                    if ($this->debug)
                        echo "SQL query failed. Check your query.<br /><br />Error Returned: ";
                        $wpdb->print_error();
                    return false;
                }
                $this->total_rows = $all_rs;
            }
            
            //Return FALSE if no rows found
            if ($this->total_rows == 0) {
                if ($this->debug)
                    echo "Query returned zero rows.";
                return FALSE;
            }
            
            //Max number of pages
            $this->max_pages = ceil($this->total_rows / $this->rows_per_page );
            if ($this->links_per_page > $this->max_pages) {
                $this->links_per_page = $this->max_pages;
            }
            
            //Check the page value just in case someone is trying to input an aribitrary value
            if ($this->page > $this->max_pages || $this->page <= 0) {
                $this->page = 1;
            }
            
            //Calculate Offset
            $this->offset = $this->rows_per_page * ($this->page - 1);
            
            //Fetch the required result set
            $rs = $wpdb->get_results($this->sql . " LIMIT {$this->offset}, {$this->rows_per_page}" );
            if (! $rs) {
                if ($this->debug)
                    echo "Pagination query failed. Check your query.<br />{$this->sql}<br />Error Returned: ";
                    $wpdb->print_error();
                return false;
            }
            return $rs;
        }
        
        /**
         * Display the link to the first page
         *
         * @access public
         * @param string $tag Text string to be displayed as the link. Defaults to 'First'
         * @return string
         */
        function renderFirst($tag = 'First') {
            if ($this->total_rows == 0)
                return FALSE;
            
            if ($this->page == 1) {
                return "$tag ";
            } else {
                if($this->js_function) {
                    return ' <a href="#" onclick="javascript: '.$this->js_function.'(1); return false;">' . $tag . '</a>';
                } else {
                    return '<a href="' . $this->php_self . '?wpppage=1' . '">' . $tag . '</a> ';
                }
            }
        }
        
        /**
         * Display the link to the last page
         *
         * @access public
         * @param string $tag Text string to be displayed as the link. Defaults to 'Last'
         * @return string
         */
        function renderLast($tag = 'Last') {
            if ($this->total_rows == 0)
                return FALSE;
            
            if ($this->page == $this->max_pages) {
                return $tag;
            } else {
                if($this->js_function) {
                    return ' <a href="#" onclick="javascript: '.$this->js_function.'('.$this->max_pages.'); return false;">' . $tag . '</a>';
                } else {
                    return ' <a href="' . $this->php_self . '?wpppage=' . $this->max_pages . '">' . $tag . '</a>';
                }
            }
        }
        
        /**
         * Display the next link
         *
         * @access public
         * @param string $tag Text string to be displayed as the link. Defaults to '>>'
         * @return string
         */
        function renderNext($tag = '&gt;&gt;') {
            if ($this->total_rows == 0)
                return FALSE;
            
            if ($this->page < $this->max_pages) {
                if($this->js_function) {
                    return ' <a href="#" onclick="javascript: '.$this->js_function.'('.($this->page + 1).'); return false;">' . $tag . '</a>';
                } else {
                    return '<a href="' . $this->php_self . '?wpppage=' . ($this->page + 1) . '">' . $tag . '</a>';
                }
            } else {
                return $tag;
            }
        }
        
        /**
         * Display the previous link
         *
         * @access public
         * @param string $tag Text string to be displayed as the link. Defaults to '<<'
         * @return string
         */
        function renderPrev($tag = '&lt;&lt;') {
            if ($this->total_rows == 0)
                return FALSE;
            
            if ($this->page > 1) {
                if($this->js_function) {
                    return ' <a href="#" onclick="javascript: '.$this->js_function.'('.($this->page - 1).'); return false;">' . $tag . '</a>';
                } else {
                    return ' <a href="' . $this->php_self . '?wpppage=' . ($this->page - 1) . '">' . $tag . '</a>';
                }
            } else {
                return " $tag";
            }
        }
        
        /**
         * Display the page links
         *
         * @access public
         * @return string
         */
        function renderNav($prefix = '<span class="page_link">', $suffix = '</span>') {
            if ($this->total_rows == 0)
                return FALSE;
            
            $batch = ceil($this->page / $this->links_per_page );
            $end = $batch * $this->links_per_page;
            if ($end == $this->page) {
                //$end = $end + $this->links_per_page - 1;
            //$end = $end + ceil($this->links_per_page/2);
            }
            if ($end > $this->max_pages) {
                $end = $this->max_pages;
            }
            $start = $end - $this->links_per_page + 1;
            $links = '';
            
            for($i = $start; $i <= $end; $i ++) {
                if ($i == $this->page) {
                    $links .= $prefix . " $i " . $suffix;
                } else {
					if($this->js_function) {
						$links .= ' ' . $prefix . '<a href="#" onclick="javascript: '.$this->js_function.'('.$i.'); return false;">' . $i . '</a>' . $suffix . ' ';
					} else {
						$links .= ' ' . $prefix . '<a href="' . $this->php_self . '?wpppage=' . $i . '">' . $i . '</a>' . $suffix . ' ';
					}
                }
            }
            
            return $links;
        }
        
        /**
         * Display full pagination navigation
         *
         * @access public
         * @return string
         */
        function renderFullNav() {
            return $this->renderFirst() . '&nbsp;' . $this->renderPrev() . '&nbsp;' . $this->renderNav() . '&nbsp;' . $this->renderNext() . '&nbsp;' . $this->renderLast();
        }
        
        /**
         * Set debug mode
         *
         * @access public
         * @param bool $debug Set to TRUE to enable debug messages
         * @return void
         */
        function setDebug($debug) {
            $this->debug = $debug;
        }
    }
}

?>
